#
# spec file for package cdrdao
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cdrdao
Version:        1.2.5
Release:        1.7
Summary:        Tool to write CD-Rs in Disk-At-Once Mode
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/CD/Record
URL:            http://cdrdao.sourceforge.net/
Source0:        http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.bz2
# PATCH-FIX-OPENSUSE cdrdao-build.patch
Patch0:         cdrdao-build.patch
# PATCH-FIX-OPENSUSE cdrdao-fixes.patch bnc#424635 nadvornik@suse.cz -- Fix cdrdao segfault
Patch1:         cdrdao-fixes.patch
# PATCH-FIX-OPENSUSE cdrdao-1.2.3-stat.patch asterios.dramis@gmail.com -- Missing includes causes failure build (patch taken from Fedora)
Patch2:         cdrdao-1.2.3-stat.patch
# PATCH-FIX-OPENSUSE cdrdao-drop-gconf-dep.patch -- Drop dependency on gconf2
Patch3:         cdrdao-drop-gconf-dep.patch
BuildRequires:  gcc-c++
BuildRequires:  libao-devel
BuildRequires:  libsigc++2-devel
BuildRequires:  libvorbis-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(mad)
Obsoletes:      gcdmaster <= 1.2.4

%description
CDRDAO creates CD-Rs in disk-at-once (DAO) mode driven by a description
file called a TOC file. In DAO mode, it is possible to create
non-standard track pregaps that have lengths other than 2 seconds and
contain nonzero audio data. This is useful for dividing live recordings
into tracks where 2 second gaps would be irritating.

%prep
%autosetup -p1

%build
%configure \
	--without-scglib
%make_build

%install
%make_install

%files
%license COPYING
%doc AUTHORS CREDITS ChangeLog README README.PlexDAE cdrdao.lsm
%doc contrib/wav2dao/wav2dao.pl
%{_bindir}/cdrdao
%{_bindir}/cue2toc
%{_bindir}/toc2cddb
%{_bindir}/toc2cue
%{_datadir}/cdrdao/
%{_mandir}/man1/cue2toc.1%{?ext_man}
%{_mandir}/man1/cdrdao.1%{?ext_man}
%{_mandir}/man1/toc2cddb.1%{?ext_man}
%{_mandir}/man1/toc2cue.1%{?ext_man}

%changelog
* Fri Dec  8 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 1.2.5:
  * gcdmaster port to GTK 3 (Stefan Roellin)
  * Support to specify encoding in TOC (Denis Leroy):
  * one of ENCODING_ISO_8859_1, ENCODING_ASCII, ENCODING_MS_JIS, ENCODING_KOREAN, ENCODING_MANDARIN
    may be specified on LANGUAGE section.
  * TOC always dumped in UTF-8, unless --no-utf8 is specified
  * Fix --swap argument with generic-mmc-raw driver (Alex Free)
  * cdrdao:
    + new cdtext command to dump CD-TEXT disc content
    + deprecate 0x10 driver option by checking device configuration
  * toc2cue: (Jonathan Simpson)
    + add option to convert bin file, removing subchannel data that isn't supported by cue/bin files
    + add option to swap byte order when creating new bin file
  * toc2mp3: (DL)
    + -J option to force specific text decoding
    + support for character encoding in filenames and id3v2 tags
    + Fix eject by first issuing PREVENT ALLOW MEDIUM REMOVAL (DL)
    + Removed scsilib snapshot from old cdrecord project, only use native interface. RIP Jörg Schilling.
    + Misc compile and warning fixes for newer C++ compilers (Fedora)
    + Cddb server updates.
* Fri Apr  3 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.2.4:
  * Fixed autocon warnings (Denis Leroy)
  * Ported to lame 3.100 (from Fedora)
  * G++ compile fixes (Nick Bailey)
  * Renamed xdao folder to gcdmaster (Denis Leroy)
  * pccts format security patch (from Fedora)
  * Fixed compile issues with glibc >= 2.12
  * Gcdmaster segfault fix (Adrian Knoth)
  * Prevent a FTBFS on kfreebsd (Christoph Egger)
  * Also look in /etc/default/cdrdao config (Andrew Suffield)
  * Fix printf format security issues (Frantisek Kluknavsky Fedora)
  * Add missing options to man page (Honza Horák)
  * CD_TEXT fix for HL-DT-ST (Kees Cook)
  * Man page hyphen fixes (Markus Koschany)
  * Some updates to the old scsilib smake files (Ubuntu patches)
- Drop no longer needed patches:
  * cdrdao-1.2.2-scan.patch
  * cdrdao-gcc6-fixes.patch
* Fri Aug 30 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Add cdrdao-drop-gconf-dep.patch: Drop dependency on gconf2.
  Patch taken from debian.
- Following the above, drop gconf2-devel BuildRequires.
- Refresh patches with quilt.
- Run spec-cleaner, use modern macros.
* Sun Jun  2 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
- Remove redundant %%clean section.
* Wed Apr 24 2019 Adam Majer <adam.majer@suse.de>
- Run autoreconf to fix build with LTO (bsc#1133112)
* Fri Aug 25 2017 olaf@aepfle.de
- Remove conditionals for lame and mad
* Tue May 24 2016 dimstar@opensuse.org
- Add cdrdao-gcc6-fixes.patch: Fix build with gcc6.
* Tue Apr 16 2013 dimstar@opensuse.org
- Drop gcdmaster: gcdmaster depends on no longer maintained GUI
  libraries from GNOME 2.
  + Obsolete gcdmaster from cdrdao.
  + Drop gtkmm2-devel, libgnomeuimm-devel and update-desktop-files
    BuildRequires: they were only needed for gcdmaster.
  + Drop cdrdao-1.2.2-desktop.patch: we won't install the .desktop
    file, so we don't need to fix it.
* Sat Sep  3 2011 asterios.dramis@gmail.com
- update to 1.2.3:
  * By default, cdrdao tries to build with a native SCSI interface.
  * Complete rewrite of native Linux SG driver.
  * Added support for new FIRST_TRACK_NO keyword to allow a CD to start with a
    track number other than 1.
  * Added native interfaces for Irix, Mac OSX and NetBSD.
  * Fixed old pregap length off-by-one error, see bug #604751.
  * Fixed bug in Toc file parser track length computation.
  * Man page typo fixes.
  * Cygwin compilation fixes. Other various compilation warning fixes.
  * Some scsilib fixes for FreeBSD, 32-bit and 64-bit SPARC.
  * Some makefile changes to avoid conflict with installed system libs.
  * Added patch to fix ARM and MIPS scsilib compile.
  * Added man pages for toc2cue and toc2cddb, from Debian.
  * Move privilege drop earlier in main flow.
  * Commited Gentoo patch for CD-TEXT track check fix.
  GCDMaster changes:
  * Preferences now stored in GConf, exports schema file.
  * Added simple Preferences dialog to change temporary file directory.
  * Fixed GCC 4.3 compilation issues.
- Spec file updates:
  * Changed License: to GPL-2.0+.
  * Added description for the patches based on openSUSE Patches Guidelines.
  * Added gtkmm2-devel, libsigc++2-devel, pkg-config in BuildRequires:.
  * Removed wodim-devel from BuildRequires: (the package now uses a native SCSI
    interface).
  * Added mimeinfo scriptlet for the mime file installed by the package.
  * Minor other updates.
- Rebased cdrdao-build.patch, cdrdao-1.2.2-scan.patch and cdrdao-fixes.patch to
  apply cleanly.
- Removed cdrdao-1.2.2-include.patch, cdrdao-1.2.2-sigc.patch and
  cdrdao-1.2.2-libnsl.patch (fixed upstream).
- Removed cdrdao-1.2.2-usal.patch (the package now uses a native SCSI
  interface).
- Added cdrdao-1.2.3-stat.patch (taken from Fedora) to fix missing includes
  that cause failure build.
- Added cdrdao-1.2.2-desktop.patch (taken from Fedora) to make the desktop file
  XDG compatible and add MimeType entries.
* Sun Oct 31 2010 jengelh@medozas.de
- Use %%_smp_mflags
* Fri Jun 26 2009 nadvornik@suse.cz
- fixed various problems with the code [bnc#491043, bnc#424635]
* Mon Apr 28 2008 nadvornik@suse.cz
- removed unneeded library dependency (libnsl.patch) [bnc#384164]
* Tue Apr  8 2008 nadvornik@suse.cz
- fixed to compile (sigc.patch)
* Wed Oct 24 2007 nadvornik@suse.cz
- include missing string.h
* Wed Jan 31 2007 sbrabec@suse.cz
- Prefix of gcdmaster changed to /usr.
- Spec file cleanup.
* Tue Jan 23 2007 nadvornik@suse.cz
- build with libusal from cdrkit
* Thu Oct  5 2006 nadvornik@suse.cz
- update to 1.2.2:
  * bugfixes, compilation fixes
  * updaed driver table
- dropped unneeded patches, including resmgr patch
* Sun Feb 19 2006 aj@suse.de
- Reduce BuildRequires.
* Tue Jan 31 2006 nadvornik@suse.cz
- do not scan old ATAPI interface [#144861]
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 24 2006 nadvornik@suse.cz
- fixed detection of libgnomeuimm
* Wed Dec 14 2005 ro@suse.de
- removed /usr/share/mime directory from filelist
  (in filesystem package now)
* Tue Nov  1 2005 nadvornik@suse.cz
- updated to 1.2.0
* Sun Aug  7 2005 ro@suse.de
- update to cvs to fix build of gcdmaster with gnome-2.6
* Sun Aug  7 2005 ro@suse.de
- find new libgnomeuimm
* Wed Apr 20 2005 nadvornik@suse.de
- fixed to compile with gcc4
* Fri Feb 11 2005 ro@suse.de
- change neededforbuild to libsigc++12
* Thu Sep 23 2004 nadvornik@suse.cz
- built with internal pccts [#45343]
* Thu Jul  1 2004 nadvornik@suse.cz
- updated to 1.1.9
- MMC-driver auto-detection in mainstream, corresponding SUSE patch dropped
- fixed [#42615]
* Mon Apr 19 2004 ro@suse.de
- fix warning: control reaches end of non-void function
* Fri Apr  2 2004 nadvornik@suse.cz
- fixed sound in gcdmaster [#33948]
* Mon Mar 29 2004 nadvornik@suse.cz
- fixed bug in dynamic menus [#36638]
* Fri Feb 20 2004 nadvornik@suse.cz
- scan for ATA devices
* Wed Feb 18 2004 nadvornik@suse.cz
- updated to 1.1.8
  - ported to gnome2
* Mon Feb  2 2004 nadvornik@suse.cz
- fixed a crash caused by wrong assert [#32701]
- fixed the fallback driver patch [#33646]
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Tue Sep 16 2003 nadvornik@suse.cz
- added fallback to generic-mmc if no other driver is detected [#31044]
* Sun Sep  7 2003 adrian@suse.de
- add Categories
* Sun Aug 31 2003 ro@suse.de
- change version string to 1.1.7-suse
- use current libscg from cdrecord
- backport "drive-info" command from cvs
- backport libscg interface changes from cvs
* Thu Aug 14 2003 nadvornik@suse.cz
- added GDR8160B to driver list [#26860]
* Thu Jul 24 2003 uli@suse.de
- fixed to build on s390x
* Fri Mar  7 2003 meissner@suse.de
- added resmgr support, rerun autoconf to bring in new
  resmgr checks.
* Tue Feb 11 2003 nadvornik@suse.cz
- updated to 1.1.7
* Sun Jan 26 2003 ro@suse.de
- fix gcc-3.3 build
* Mon Jan 20 2003 ro@suse.de
- fix multiline-string issue in code
* Fri Sep 27 2002 ro@suse.de
- Added alsa alsa-devel to neededforbuild (esound)
* Mon Aug  5 2002 nadvornik@suse.cz
- updated driver table
* Tue Jul 23 2002 nadvornik@suse.cz
- installed toc2cue (bug #17144)
* Mon Jun 17 2002 meissner@suse.de
- use ppc config file for ppc64 too.
* Tue May 14 2002 ro@suse.de
- fix to build on x86_64 and with pccts includes in lib64
* Fri Apr 26 2002 ro@suse.de
- fix build with latest gcc
* Mon Apr 22 2002 ro@suse.de
- make it build with gcc-3.1
* Fri Sep  7 2001 nadvornik@suse.cz
- added /usr/share/cdrdao to filelist
* Wed Aug 29 2001 schwab@suse.de
- Add %%suse_update_config.
- Fix configuration problem.
* Fri Aug  3 2001 uli@suse.de
- added rules for s390
* Wed Jun 20 2001 nadvornik@suse.cz
- created subpackage "gcdmaster"
* Wed May 30 2001 egger@suse.de
- Updated to version 1.1.5.
- Fixed specfile.
- Enabled GNOME frontend (to be moved into subpackage).
- Completed #neededforbuild.
* Wed May  9 2001 mfabian@suse.de
- bzip2 sources
* Tue Feb 20 2001 sf@suse.de
- added ia64 to RULES
- added ia64 to btorder.h
- added <string.h> for gcc-2.96
* Fri Feb  9 2001 ro@suse.de
- fixed to compile
- sigc++, sigc++-devel need to be added to neededforbuild,
  but xdao does not compile with current gtk anyway
* Sun Nov  5 2000 ro@suse.de
- fixed neededforbuild
* Thu Jul  6 2000 kukuk@suse.de
- Add patch for SPARC
* Fri May 19 2000 smid@suse.cz
- man pages fixed
* Thu Apr  6 2000 smid@suse.cz
- buildroot added
* Mon Jan 17 2000 ro@suse.de
- man to usr/share/man
* Mon Nov  8 1999 ro@suse.de
- update to 1.1.3 (added xcdrdao, gtk-frontend)
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Aug  3 1999 uli@suse.de
- update -> 1.1.2
* Fri Apr 16 1999 ro@suse.de
- update to 1.1.0
* Tue Dec  1 1998 ro@suse.de
- update to 1.09
* Mon Sep 14 1998 ro@suse.de
- initial suse package, development version 1.06
